module GraphicsTime
	( Time
	, getTime
	) where

import Word( Word32 )
import Win32Misc(timeGetTime)

----------------------------------------------------------------
-- The interface
----------------------------------------------------------------

type Time = Word32
getTime      :: IO Time

----------------------------------------------------------------
-- The implementation
----------------------------------------------------------------

getTime = Win32Misc.timeGetTime

----------------------------------------------------------------
-- The end
----------------------------------------------------------------

